package
Version:
v0.0.0-...-7cc471b
Opens a new window with list of versions in this module.
Published: Oct 21, 2025
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Location struct {
Name string `json:"name"`
Active bool `json:"active"`
SigLev int32 `json:"siglev"`
}
Location represents node location
type Result struct {
Time time.Time `json:"time"`
Locations []Location `json:"locations"`
Raw string `json:"raw"`
}
Result represents a single log record from /tmp/sql_state
Source Files
¶
Click to show internal directories.
Click to hide internal directories.